@@ -247,24 +247,24 @@ static gboolean
 key_press_cb (GtkWidget *widget, GdkEventKey *event, GWeatherApplet *gw_applet)
 {
 	switch (event->keyval) {	
-	case GDK_u:
+	case GDK_KEY_u:
 		if (event->state == GDK_CONTROL_MASK) {
 			gweather_update (gw_applet);
 			return TRUE;
 		}
 		break;
-	case GDK_d:
+	case GDK_KEY_d:
 		if (event->state == GDK_CONTROL_MASK) {
 			details_cb (NULL, gw_applet);
 			return TRUE;
 		}
 		break;		
-	case GDK_KP_Enter:
-	case GDK_ISO_Enter:
-	case GDK_3270_Enter:
-	case GDK_Return:
-	case GDK_space:
-	case GDK_KP_Space:
+	case GDK_KEY_KP_Enter:
+	case GDK_KEY_ISO_Enter:
+	case GDK_KEY_3270_Enter:
+	case GDK_KEY_Return:
+	case GDK_KEY_space:
+	case GDK_KEY_KP_Space:
 		details_cb (NULL, gw_applet);
 		return TRUE;
 	default:
@@ -339,7 +339,7 @@ void gweather_applet_create (GWeatherApplet *gw_applet)
                        G_CALLBACK(size_allocate_cb), gw_applet);
     g_signal_connect (G_OBJECT(gw_applet->applet), "destroy", 
                        G_CALLBACK (applet_destroy), gw_applet);
-    g_signal_connect (GTK_OBJECT(gw_applet->applet), "button_press_event",
+    g_signal_connect (G_OBJECT(gw_applet->applet), "button_press_event",
                        G_CALLBACK(clicked_cb), gw_applet);
     g_signal_connect (G_OBJECT(gw_applet->applet), "key_press_event",           
 			G_CALLBACK(key_press_cb), gw_applet);
@@ -394,7 +394,6 @@ update_finish (WeatherInfo *info, gpointer data)
     static int gw_fault_counter = 0;
 #ifdef HAVE_LIBNOTIFY
     char *message, *detail;
-    GConfClient *conf;
 #endif
     char *s;
     GWeatherApplet *gw_applet = (GWeatherApplet *)data;
@@ -471,8 +470,7 @@ update_finish (WeatherInfo *info, gpointer data)
 			 if (icon == NULL)
 				 icon = "stock-unknown";
 	           	 
-			 n = notify_notification_new (message, detail, icon,
-					 gw_applet->container);
+			 n = notify_notification_new (message, detail, icon);
 	
 		   	 notify_notification_show (n, &error);
 			 if (error)
